@@ -1,15 +1,13 @@
 from .buttons import CallbackButton, UrlButton
 from .contexts import (
-    QueryCallback,
     QueryContext,
-    TextCallback,
     TextContext,
-    UpdateCallback,
     UpdateContext,
 )
 from .handlers import (
     CommandHandler,
     CompositeHandler,
+    InlineMenuHandler,
     MessageHandler,
     QueryHandler,
     StartGroupHandler,
@@ -33,10 +31,8 @@ __all__ = [
     "CommandHandler",
     "StartHandler",
     "StartGroupHandler",
+    "InlineMenuHandler",
     "UpdateContext",
     "QueryContext",
     "TextContext",
-    "UpdateCallback",
-    "QueryCallback",
-    "TextCallback",
 ]
