@@ -1,5 +1,6 @@
 from .command import CommandHandler
 from .composite import CompositeHandler
+from .inline_menu import InlineMenuHandler
 from .message import MessageHandler
 from .query import QueryHandler
 from .start import (
@@ -16,4 +17,5 @@ __all__ = [
     "CommandHandler",
     "StartHandler",
     "StartGroupHandler",
+    "InlineMenuHandler",
 ]
