@@ -1,4 +1,4 @@
-from botty_core.types import PTBContext, PTBHandler
+from botty_core import PTBContext, PTBHandler
 from telegram import Update
 
 
